==> kubernetes-model-1.0.43-sources.jar: annotations/io/fabric8/kubernetes/api/model/PersistentVolumeClaimFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class PersistentVolumeClaimFluentImpl<T extends PersistentVolumeClaimFluent<T>> extends BaseFluent<T> implements PersistentVolumeClaimFluent<T>{

     PersistentVolumeClaim.ApiVersion apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<PersistentVolumeClaimSpec, ?> spec;     VisitableBuilder<PersistentVolumeClaimStatus, ?> status;     Map<String, Object> additionalProperties = new HashMap();
public PersistentVolumeClaimFluentImpl(){
    
}
public PersistentVolumeClaimFluentImpl( PersistentVolumeClaim instance ){
    this.withApiVersion(instance.getApiVersion()); this.withKind(instance.getKind()); this.withMetadata(instance.getMetadata()); this.withSpec(instance.getSpec()); this.withStatus(instance.getStatus()); 
}

    public PersistentVolumeClaim.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( PersistentVolumeClaim.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNestedImpl<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public PersistentVolumeClaimSpec getSpec(){
    return this.spec!=null?this.spec.build():null;
    }
    public T withSpec( PersistentVolumeClaimSpec spec){
    if (spec!=null){ this.spec= new PersistentVolumeClaimSpecBuilder(spec); _visitables.add(this.spec);} return (T) this;
    }
    public SpecNested<T> withNewSpec(){
    return new SpecNestedImpl<T>();
    }
    public SpecNested<T> withNewSpecLike( PersistentVolumeClaimSpec item){
    return new SpecNestedImpl<T>(item);
    }
    public SpecNested<T> editSpec(){
    return withNewSpecLike(getSpec());
    }
    public PersistentVolumeClaimStatus getStatus(){
    return this.status!=null?this.status.build():null;
    }
    public T withStatus( PersistentVolumeClaimStatus status){
    if (status!=null){ this.status= new PersistentVolumeClaimStatusBuilder(status); _visitables.add(this.status);} return (T) this;
    }
    public StatusNested<T> withNewStatus(){
    return new StatusNestedImpl<T>();
    }
    public StatusNested<T> withNewStatusLike( PersistentVolumeClaimStatus item){
    return new StatusNestedImpl<T>(item);
    }
    public StatusNested<T> editStatus(){
    return withNewStatusLike(getStatus());
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public T addToAdditionalProperties( Map<String, Object> map){
    if(map != null) { this.additionalProperties.putAll(map);} return (T)this;
    }
    public T removeFromAdditionalProperties( String key){
    if(key != null) {this.additionalProperties.remove(key);} return (T)this;
    }
    public T removeFromAdditionalProperties( Map<String, Object> map){
    if(map != null) { for(Object key : map.keySet()) {this.additionalProperties.remove(key);}} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
PersistentVolumeClaimFluentImpl that = (PersistentVolumeClaimFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
return true;

    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
    
            public N and(){
            return (N) PersistentVolumeClaimFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class SpecNestedImpl<N> extends PersistentVolumeClaimSpecFluentImpl<SpecNested<N>> implements SpecNested<N>{

        private final PersistentVolumeClaimSpecBuilder builder;
    
             SpecNestedImpl (){
        this.builder = new PersistentVolumeClaimSpecBuilder(this);
        }
             SpecNestedImpl ( PersistentVolumeClaimSpec item){
        this.builder = new PersistentVolumeClaimSpecBuilder(this, item);
        }
    
            public N endSpec(){
            return and();
        }
            public N and(){
            return (N) PersistentVolumeClaimFluentImpl.this.withSpec(builder.build());
        }
    
}
    public class StatusNestedImpl<N> extends PersistentVolumeClaimStatusFluentImpl<StatusNested<N>> implements StatusNested<N>{

        private final PersistentVolumeClaimStatusBuilder builder;
    
             StatusNestedImpl (){
        this.builder = new PersistentVolumeClaimStatusBuilder(this);
        }
             StatusNestedImpl ( PersistentVolumeClaimStatus item){
        this.builder = new PersistentVolumeClaimStatusBuilder(this, item);
        }
    
            public N and(){
            return (N) PersistentVolumeClaimFluentImpl.this.withStatus(builder.build());
        }
            public N endStatus(){
            return and();
        }
    
}


}

==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/kubernetes/api/model/PersistentVolumeClaimFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.util.Map;
import java.util.Map;
import java.util.HashMap;
import java.io.Serializable;
import java.util.AbstractMap;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;

public class PersistentVolumeClaimFluentImpl<A extends PersistentVolumeClaimFluent<A>> extends BaseFluent<A> implements PersistentVolumeClaimFluent<A>{

     String apiVersion;     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     VisitableBuilder<PersistentVolumeClaimSpec, ?> spec;     VisitableBuilder<PersistentVolumeClaimStatus, ?> status;
public PersistentVolumeClaimFluentImpl(){
    
}
public PersistentVolumeClaimFluentImpl( PersistentVolumeClaim instance ){
    this.withApiVersion(instance.getApiVersion()); this.withKind(instance.getKind()); this.withMetadata(instance.getMetadata()); this.withSpec(instance.getSpec()); this.withStatus(instance.getStatus()); 
}

    public String getApiVersion(){
    return this.apiVersion;
    }
    public A withApiVersion( String apiVersion){
    this.apiVersion=apiVersion; return (A) this;
    }
    public String getKind(){
    return this.kind;
    }
    public A withKind( String kind){
    this.kind=kind; return (A) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public A withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }
    public MetadataNested<A> withNewMetadata(){
    return new MetadataNestedImpl();
    }
    public MetadataNested<A> withNewMetadataLike( ObjectMeta item){
    return new MetadataNestedImpl(item);
    }
    public MetadataNested<A> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public PersistentVolumeClaimSpec getSpec(){
    return this.spec!=null?this.spec.build():null;
    }
    public A withSpec( PersistentVolumeClaimSpec spec){
    if (spec!=null){ this.spec= new PersistentVolumeClaimSpecBuilder(spec); _visitables.add(this.spec);} return (A) this;
    }
    public SpecNested<A> withNewSpec(){
    return new SpecNestedImpl();
    }
    public SpecNested<A> withNewSpecLike( PersistentVolumeClaimSpec item){
    return new SpecNestedImpl(item);
    }
    public SpecNested<A> editSpec(){
    return withNewSpecLike(getSpec());
    }
    public PersistentVolumeClaimStatus getStatus(){
    return this.status!=null?this.status.build():null;
    }
    public A withStatus( PersistentVolumeClaimStatus status){
    if (status!=null){ this.status= new PersistentVolumeClaimStatusBuilder(status); _visitables.add(this.status);} return (A) this;
    }
    public StatusNested<A> withNewStatus(){
    return new StatusNestedImpl();
    }
    public StatusNested<A> withNewStatusLike( PersistentVolumeClaimStatus item){
    return new StatusNestedImpl(item);
    }
    public StatusNested<A> editStatus(){
    return withNewStatusLike(getStatus());
    }
    public boolean equals( Object o){
    
if (this == o) return true;
if (o == null || getClass() != o.getClass()) return false;
PersistentVolumeClaimFluentImpl that = (PersistentVolumeClaimFluentImpl) o;
if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
if (status != null ? !status.equals(that.status) :that.status != null) return false;
return true;

    }

    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<MetadataNested<N>> implements MetadataNested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNestedImpl ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
             MetadataNestedImpl (){
        this.builder = new ObjectMetaBuilder(this);
        }
    
            public N and(){
            return (N) PersistentVolumeClaimFluentImpl.this.withMetadata(builder.build());
        }
            public N endMetadata(){
            return and();
        }
    
}
    public class SpecNestedImpl<N> extends PersistentVolumeClaimSpecFluentImpl<SpecNested<N>> implements SpecNested<N>{

        private final PersistentVolumeClaimSpecBuilder builder;
    
             SpecNestedImpl (){
        this.builder = new PersistentVolumeClaimSpecBuilder(this);
        }
             SpecNestedImpl ( PersistentVolumeClaimSpec item){
        this.builder = new PersistentVolumeClaimSpecBuilder(this, item);
        }
    
            public N endSpec(){
            return and();
        }
            public N and(){
            return (N) PersistentVolumeClaimFluentImpl.this.withSpec(builder.build());
        }
    
}
    public class StatusNestedImpl<N> extends PersistentVolumeClaimStatusFluentImpl<StatusNested<N>> implements StatusNested<N>{

        private final PersistentVolumeClaimStatusBuilder builder;
    
             StatusNestedImpl (){
        this.builder = new PersistentVolumeClaimStatusBuilder(this);
        }
             StatusNestedImpl ( PersistentVolumeClaimStatus item){
        this.builder = new PersistentVolumeClaimStatusBuilder(this, item);
        }
    
            public N and(){
            return (N) PersistentVolumeClaimFluentImpl.this.withStatus(builder.build());
        }
            public N endStatus(){
            return and();
        }
    
}


}
